devicesinlan_gui - Turulomio

# NAME

devicesinlan_gui: Analyse tous les appareils de votre LAN. Ensuite, vous pouvez définir un alias pour vos appareils connus afin de détecter de futurs appareils étranges dans votre réseau.

# SYNOPSIS

devicesinlan_gui [--help] [--version] [--debug DEBUG]

# LA DESCRIPTION

Dans le menu de l'application, vous disposez des fonctionnalités suivantes :

Appareils > Nouveau scan

Recherche tous les appareils du réseau local et les affiche dans un nouvel onglet. Si un appareil ne figure pas dans la liste des appareils connus, il s'affichera avec un fond rouge. Les appareils avec un fond vert sont des appareils de confiance

Appareils > Afficher la base de données des appareils

Affiche tous les appareils connus dans un nouvel onglet.

Le clic droit vous permet de modifier la base de données des appareils connus.

Appareils > Charger la liste des appareils

Charge une liste d'appareils connus au format xml.

Appareils > Enregistrer la liste des appareils

Enregistre la liste des appareils connus dans un fichier xml.

Appareils > Réinitialiser la base de données

Supprime tous les appareils connus.

Cette option efface tous les appareils connus de la base de données.

Configuration > Paramètres

Dans cette boîte de dialogue, vous pouvez sélectionner votre langue préférée et configurer le nombre de requêtes simultanées.

Aide > Aide

Affiche ces informations d'aide.

Aide > À propos

Affiche des informations sur la licence et les auteurs de DevicesInLAN.

Aide > Rechercher les mises à jour

Recherche les mises à jour dans le référentiel DevicesInLan.

Aide > Quitter

Quitte le programme.

Created with libmangenerator at 2025-12-28